﻿using Android.App;
using Android.OS;
using System.IO;
using ThinkGeo.MapSuite.AndroidEdition;
using ThinkGeo.MapSuite.Core;

namespace HelloWorld
{
    [Activity(Label = "HelloWorld", MainLauncher = true, Icon = "@drawable/icon")]
    public class MainActivity : Activity
    {
        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);
            SetContentView(Resource.Layout.Main);

            string targetDirectory = (@"/mnt/sdcard/Android.Sample/GetStarted/");
            CopySampleData(targetDirectory);

            MapView mapView = FindViewById<MapView>(Resource.Id.MapView);
            mapView.MapUnit = GeographyUnit.DecimalDegree;

            //WorldMapKitOverlay worldMapKitOverlay = new WorldMapKitOverlay();
            //mapView.Overlays.Add("WorldMapKit", worldMapKitOverlay);

            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(Path.Combine(targetDirectory, "cntry02.shp"));
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            ShapeFileFeatureLayer capitalLayer = new ShapeFileFeatureLayer(Path.Combine(targetDirectory, "capital.shp"));
            // We can customize our own Style. Here we pass in a color and size.
            capitalLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.White, 7, GeoColor.StandardColors.Brown);
            capitalLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("CITY_NAME", "Arial", 8, DrawingFontStyles.Italic, GeoColor.StandardColors.Black, 3, 3);
            // The Style we set here is available from ZoomLevel01 to ZoomLevel05. That means if we zoom in a bit more, it will no longer be visible.
            capitalLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay overlay = new LayerOverlay();
            overlay.Opacity = 0.8;
            overlay.Layers.Add(worldLayer);
            overlay.Layers.Add(capitalLayer);

            mapView.Overlays.Add("Countries02", overlay);

            // Option 1: change the currentExtent to accord the map to a real-world coordinate.
            //mapView.CurrentExtent = new RectangleShape(5, 78, 30, 26);

            // Option 2: use Center and Scale
            RunOnUiThread(() =>
            {
                ZoomLevelSet decimalDegreeZoomLevelSet = new ZoomLevelSet();
                PointShape center = new PointShape(30, 26);
                mapView.ZoomTo(center, decimalDegreeZoomLevelSet.ZoomLevel08.Scale);
            });
        }

        private void CopySampleData(string targetDirectory)
        {
            if (!Directory.Exists(targetDirectory))
            {
                Directory.CreateDirectory(targetDirectory);
                foreach (string filename in Assets.List("AppData"))
                {
                    Stream stream = Assets.Open("AppData/" + filename);
                    FileStream fileStream = File.Create(Path.Combine(targetDirectory, filename));
                    stream.CopyTo(fileStream);
                    fileStream.Close();
                    stream.Close();
                }
            }
        }
    }
}

